#
# spec file for package python-tox
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-tox
Version:        1.9.2
Release:        6.3
Summary:        Virtualenv-based automation of test activities
License:        MIT
Group:          Development/Languages/Python
Url:            http://tox.testrun.org/
Source:         http://pypi.python.org/packages/source/t/tox/tox-%{version}.tar.gz
# PATCH-FIX-OPENSUSE speilicke@suse.com -- Due to update-alternative usage, some bianries aren't available at build-time
Patch0:         tox-disable-env-tests.patch
BuildRequires:  python-devel
# Documentation requirements:
BuildRequires:  python-Sphinx
# Test requirements:
BuildRequires:  python-pip
BuildRequires:  python-py >= 1.4.17
BuildRequires:  python-pytest >= 2.3.5
BuildRequires:  python-virtualenv >= 1.11.2
BuildRequires:  unzip
Requires:       python-py >= 1.4.17
Requires:       python-virtualenv >= 1.11.2
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
BuildRequires:  python-argparse
Requires:       python-argparse
%else
BuildArch:      noarch
%endif

%description
Tox as is a generic virtualenv management and test command line tool you can
use for:

* checking your package installs correctly with different
  Python versions and interpreters

* running your tests in each of the
  environments, configuring your test tool of choice

* acting as a frontend to Continuous Integration
  servers, greatly reducing boilerplate and merging
  CI and shell-based testing.

%prep
%setup -q -n tox-%{version}
%patch0 -p1
sed -i -e "/^\\[testenv\\]/ a\\sitepackages = True" tox.ini
sed -i -e "s/tox=tox:cmdline/tox-%{py_ver}=tox:cmdline/" \
       -e "s/tox-quickstart=tox._quickstart:main/tox-quickstart-%{py_ver}=tox._quickstart:main/" setup.py

%build
python setup.py build
cd doc && make html && rm -r _build/html/.buildinfo # Generate HTML documentation

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for B in tox tox-quickstart ; do
  touch %{buildroot}%{_sysconfdir}/alternatives/$B
  ln -sf %{_sysconfdir}/alternatives/$B %{buildroot}/%{_bindir}/$B
done

%check
PATH=%{buildroot}%{_bindir}:$PATH PYTHONPATH=%{buildroot}%{python_sitelib}/ py.test

%post
update-alternatives \
    --install %{_bindir}/tox tox %{_bindir}/tox-%{py_ver} 20 \
    --slave %{_bindir}/tox-quickstart tox-quickstart %{_bindir}/tox-quickstart-%{py_ver}

%postun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove tox %{_bindir}/tox-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst doc/_build/html
%{_bindir}/tox
%{_bindir}/tox-%{py_ver}
%ghost %{_sysconfdir}/alternatives/tox
%{_bindir}/tox-quickstart
%{_bindir}/tox-quickstart-%{py_ver}
%ghost %{_sysconfdir}/alternatives/tox-quickstart
%{python_sitelib}/tox-%{version}-py%{py_ver}.egg-info
%{python_sitelib}/tox

%changelog
* Sat May  2 2015 benoit.monin@gmx.fr
- update to version 1.9.2:
  * backout ability that --force-deps substitutes name/versions in
    requirement files due to various issues. This fixes issue228,
    fixes issue230, fixes issue231 which popped up with 1.9.1.
- additional changes from version 1.9.1:
  * use a file instead of a pipe for command output in
    "--result-json". Fixes some termination issues with python2.6.
  * allow --force-deps to override dependencies in "-r"
    requirements files.  Thanks Sontek for the PR.
  * fix issue227: use "-m virtualenv" instead of "-mvirtualenv" to
    make it work with pyrun.  Thanks Marc-Andre Lemburg.
- additional changes from version 1.9.0:
  * fix issue193: Remove ``--pre`` from the default
    ``install_command``; by default tox will now only install final
    releases from PyPI for unpinned dependencies. Use ``pip_pre =
    true`` in a testenv or the ``--pre`` command-line option to
    restore the previous behavior.
  * fix issue199: fill resultlog structure ahead of virtualenv
    creation
  * refine determination if we run from Jenkins, thanks Borge Lanes.
  * echo output to stdout when ``--report-json`` is used
  * fix issue11: add a ``skip_install`` per-testenv setting which
    prevents the installation of a package. Thanks Julian Krause.
  * fix issue124: ignore command exit codes; when a command has a
    "-" prefix, tox will ignore the exit code of that command
  * fix issue198: fix broken envlist settings, e.g.
    {py26,py27}{-lint,}
  * fix issue191: lessen factor-use checks
- additional changes from version 1.8.1:
  * fix issue190: allow setenv to be empty.
  * allow escaping curly braces with "\".  Thanks Marc Abramowitz
    for the PR.
  * allow "." names in environment names such that "py27-django1.7"
    is a valid environment name.  Thanks Alex Gaynor and Alex
    Schepanovski.
  * report subprocess exit code when execution fails.  Thanks
    Marius Gedminas.
- additional changes from version 1.8.0:
  * new multi-dimensional configuration support.  Many thanks to
    Alexander Schepanovski for the complete PR with docs. And to
    Mike Bayer and others for testing and feedback.
  * fix issue148: remove "__PYVENV_LAUNCHER__" from os.environ when
    starting subprocesses. Thanks Steven Myint.
  * fix issue152: set VIRTUAL_ENV when running test commands,
    thanks Florian Ludwig.
  * better report if we can't get version_info from an interpreter
    executable. Thanks Floris Bruynooghe.
- update project URL
- refresh tox-disable-env-tests.patch
* Mon Aug 25 2014 aj@suse.com
- Update to version 1.7.2:
  * fix issue150: parse {posargs} more like we used to do it pre
    1.7.0.
  * fix issue59: add a config variable skip-missing-interpreters as
    well as command line option --skip-missing-interpreters
  * fix issue164: better traceback info in case of failing test commands
  * support optional env variable substitution.
  * limit python hashseed to 1024 on Windows to prevent possible
    memory errors.
* Thu Jul  3 2014 speilicke@suse.com
- Update to version 1.7.1:
  - fix issue162: don't list python 2.5 as compatibiliy/supported
  - fix issue158 and fix issue155: windows/virtualenv properly works now:
    call virtualenv through "python -m virtualenv" with the same
    interpreter which invoked tox.  Thanks Chris Withers, Ionel Maries Cristian.
- Add tox-disable-env-tests.patch: Disable tests that need network-access
  and that depend on /usr/bin/tox (which is only added via u-a in %%post)
- Remove tox-disable-network-accessing-tests.patch: Obsoleted by the above patch
- Implement update-alternatives to allow parallel installation with python3-tox
* Thu Sep 19 2013 speilicke@suse.com
- (Build)Require python-argparse on SLE
* Thu Sep  5 2013 speilicke@suse.com
- Update to version 1.6.0:
  + fix issue119: {envsitepackagesdir} is now correctly computed and has
    a better test to prevent regression.
  + fix issue116: make 1.6 introduced behaviour of changing to a
    per-env HOME directory during install activities dependent
    on "--set-home" for now.  Should re-establish the old behaviour
    when no option is given.
  + fix issue118: correctly have two tests use realpath(). Thanks Barry
    Warsaw.
  + fix test runs on environments without a home directory
    (in this case we use toxinidir as the homedir)
  + fix issue117: python2.5 fix: don't use ``--insecure`` option because
    its very existence depends on presence of "ssl".  If you
    want to support python2.5/pip1.3.1 based test environments you need
    to install ssl and/or use PIP_INSECURE=1 through ``setenv``. section.
  + fix issue102: change to {toxinidir} when installing dependencies.
    this allows to use relative path like in "-rrequirements.txt".
- Changes from version 1.6.0:
  + fix issue35: add new EXPERIMENTAL "install_command" testenv-option to
    configure the installation command with options for dep/pkg install.
    Thanks Carl Meyer for the PR and docs.
  + fix issue91: python2.5 support by vendoring the virtualenv-1.9.1
    script and forcing pip<1.4. Also the default [py25] environment
    modifies the default installer_command (new config option)
    to use pip without the "--pre" option which was introduced
    with pip-1.4 and is now required if you want to install non-stable
    releases.  (tox defaults to install with "--pre" everywhere).
  + during installation of dependencies HOME is now set to a pseudo
    location ({envtmpdir}/pseudo-home).  If an index url was specified
    a .pydistutils.cfg file will be written with an index_url setting
    so that packages defining ``setup_requires`` dependencies will not
    silently use your HOME-directory settings or https://pypi.python.org.
  + fix issue1: empty setup files are properly detected, thanks Anthon van
    der Neuth
  + remove toxbootstrap.py for now because it is broken.
  + fix issue109 and fix issue111: multiple "-e" options are now combined
    (previously the last one would win). Thanks Anthon van der Neut.
  + add --result-json option to write out detailed per-venv information
    into a json report file to be used by upstream tools.
  + add new config options ``usedevelop`` and ``skipsdist`` as well as a
    command line option ``--develop`` to install the package-under-test in develop mode.
    thanks Monty Tailor for the PR.
  + always unset PYTHONDONTWRITEBYTE because newer setuptools doesn't like it
  + if a HOMEDIR cannot be determined, use the toxinidir.
  + refactor interpreter information detection to live in new
    tox/interpreters.py file, tests in tests/test_interpreters.py.
- Add tox-disable-network-accessing-tests.patch: Disable tests that insist on
  downloading dependencies over network
- Run testsuite
* Tue Jun 25 2013 dmueller@suse.com
- update to 1.5.0:
  - fix issue104: use setuptools by default, instead of distribute,
  now that setuptools has distribute merged.
  - make sure test commands are searched first in the virtualenv
  - re-fix issue2 - add whitelist_externals to be used in ``[testenv*]``
  sections, allowing to avoid warnings for commands such as ``make``,
  used from the commands value.
  - fix issue97 - allow substitutions to reference from other sections
  (thanks Krisztian Fekete)
  - fix issue92 - fix {envsitepackagesdir} to actually work again
  - show (test) command that is being executed, thanks
  Lukasz Balcerzak
  - re-license tox to MIT license
  - depend on virtualenv-1.9.1
  - rename README.txt to README.rst to make bitbucket happier
* Mon Jun 17 2013 speilicke@suse.com
- Only require argparse on SLE, it's part of Python-2.7
* Sun Apr 21 2013 toms@opensuse.org
- Update to version 1.4.3:
  See http://testrun.org/tox/latest//changelog.html for more details
- SPEC file: Added bcond with test to prepare testing. Doesn't work
  yet, but can be improved
* Thu Jul 26 2012 saschpe@suse.de
- Update to version 1.4.2:
  + fix some tests which fail if /tmp is a symlink to some other place
  + "python setup.py test" now runs tox tests via tox :)
    also added an example on how to do it for your project.
- Changes from version 1.4.1:
  + fix issue41 better quoting on windows - you can now use "<" and ">" in
    deps specifications, thanks Chris Withers for reporting
* Fri Jun 22 2012 saschpe@suse.de
- Update to version 1.4:
  + fix issue26 - no warnings on absolute or relative specified paths for commands
  + fix issue33 - commentchars are ignored in key-value settings allowing
    for specifying commands like: python -c "import sys ; print sys"
    which would formerly raise irritating errors because the ";"
    was considered a comment
  + tweak and improve reporting
  + refactor reporting and virtualenv manipulation
    to be more accessible from 3rd party tools
  + support value substitution from other sections
    with the {[section]key} syntax
  + fix issue29 - correctly point to pytest explanation
    for importing modules fully qualified
  + fix issue32 - use --system-site-packages and don't pass --no-site-packages
  + add python3.3 to the default env list, so early adopters can test
  + drop python2.4 support (you can still have your tests run on
    python-2.4, just tox itself requires 2.5 or higher.
* Tue Feb 21 2012 saschpe@suse.de
- Don't use nose, but custom script to run testsuite
* Mon Feb 20 2012 saschpe@gmx.de
- Initial version
